@@ -377,7 +377,7 @@ class Atom(metaclass=abc.ABCMeta):
         """
 
     def __str__(self):
-        return '"{}=={}"'.format(self.name, misc.get_version_string(self))
+        return f'"{self.name}=={misc.get_version_string(self)}"'
 
     def __repr__(self):
-        return '<{} {}>'.format(reflection.get_class_name(self), self)
+        return f'<{reflection.get_class_name(self)} {self}>'
