@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
 #    not use this file except in compliance with the License. You may obtain
 #    a copy of the License at
@@ -20,7 +18,6 @@ import threading
 
 from oslo_utils import excutils
 from oslo_utils import timeutils
-import six
 
 from taskflow.conductors import base
 from taskflow import exceptions as excp
@@ -34,8 +31,7 @@ from taskflow.utils import misc
 LOG = logging.getLogger(__name__)
 
 
-@six.add_metaclass(abc.ABCMeta)
-class ExecutorConductor(base.Conductor):
+class ExecutorConductor(base.Conductor, metaclass=abc.ABCMeta):
     """Dispatches jobs from blocking :py:meth:`.run` method to some executor.
 
     This conductor iterates over jobs in the provided jobboard (waiting for
@@ -106,7 +102,7 @@ class ExecutorConductor(base.Conductor):
                  persistence=None, engine=None,
                  engine_options=None, wait_timeout=None,
                  log=None, max_simultaneous_jobs=MAX_SIMULTANEOUS_JOBS):
-        super(ExecutorConductor, self).__init__(
+        super().__init__(
             name, jobboard, persistence=persistence,
             engine=engine, engine_options=engine_options)
         self._wait_timeout = tt.convert_to_timeout(
@@ -125,24 +121,19 @@ class ExecutorConductor(base.Conductor):
                                        " it has not been")
 
     def stop(self):
-        """Requests the conductor to stop dispatching.
-
-        This method can be used to request that a conductor stop its
-        consumption & dispatching loop.
-
-        The method returns immediately regardless of whether the conductor has
-        been stopped.
-        """
         self._wait_timeout.interrupt()
 
+    # Inherit the docs, so we can reference them in our class docstring,
+    # if we don't do this sphinx gets confused...
+    stop.__doc__ = base.Conductor.stop.__doc__
+
     @property
     def dispatching(self):
         """Whether or not the dispatching loop is still dispatching."""
         return not self._dead.is_set()
 
     def _listeners_from_job(self, job, engine):
-        listeners = super(ExecutorConductor, self)._listeners_from_job(
-            job, engine)
+        listeners = super()._listeners_from_job(job, engine)
         listeners.append(logging_listener.LoggingListener(engine,
                                                           log=self._log))
         return listeners
@@ -180,7 +171,7 @@ class ExecutorConductor(base.Conductor):
                     stage_func()
                     self._notifier.notify("%s_end" % event_name, details)
             except excp.WrappedFailure as e:
-                if all((f.check(*self.NO_CONSUME_EXCEPTIONS) for f in e)):
+                if all(f.check(*self.NO_CONSUME_EXCEPTIONS) for f in e):
                     consume = False
                 if self._log.isEnabledFor(logging.WARNING):
                     if consume:
@@ -211,7 +202,7 @@ class ExecutorConductor(base.Conductor):
                     self._log.info("Job completed successfully: %s", job)
             return consume
 
-    def _try_finish_job(self, job, consume):
+    def _try_finish_job(self, job, consume, trash=False):
         try:
             if consume:
                 self._jobboard.consume(job, self._name)
@@ -220,6 +211,13 @@ class ExecutorConductor(base.Conductor):
                     'conductor': self,
                     'persistence': self._persistence,
                 })
+            elif trash:
+                self._jobboard.trash(job, self._name)
+                self._notifier.notify("job_trashed", {
+                    'job': job,
+                    'conductor': self,
+                    'persistence': self._persistence,
+                })
             else:
                 self._jobboard.abandon(job, self._name)
                 self._notifier.notify("job_abandoned", {
@@ -237,6 +235,7 @@ class ExecutorConductor(base.Conductor):
 
     def _on_job_done(self, job, fut):
         consume = False
+        trash = False
         try:
             consume = fut.result()
         except KeyboardInterrupt:
@@ -244,8 +243,9 @@ class ExecutorConductor(base.Conductor):
                 self._log.warn("Job dispatching interrupted: %s", job)
         except Exception:
             self._log.warn("Job dispatching failed: %s", job, exc_info=True)
+            trash = True
         try:
-            self._try_finish_job(job, consume)
+            self._try_finish_job(job, consume, trash)
         finally:
             self._dispatched.discard(fut)
 
@@ -338,14 +338,8 @@ class ExecutorConductor(base.Conductor):
     run.__doc__ = base.Conductor.run.__doc__
 
     def wait(self, timeout=None):
-        """Waits for the conductor to gracefully exit.
-
-        This method waits for the conductor to gracefully exit. An optional
-        timeout can be provided, which will cause the method to return
-        within the specified timeout. If the timeout is reached, the returned
-        value will be ``False``, otherwise it will be ``True``.
-
-        :param timeout: Maximum number of seconds that the :meth:`wait` method
-                        should block for.
-        """
         return self._dead.wait(timeout)
+
+    # Inherit the docs, so we can reference them in our class docstring,
+    # if we don't do this sphinx gets confused...
+    wait.__doc__ = base.Conductor.wait.__doc__
