@@ -19,9 +19,7 @@ from unittest import mock
 import fixtures
 from oslotest import base
 
-from testtools import compat
 from testtools import matchers
-from testtools import testcase
 
 from taskflow import exceptions
 from taskflow.tests import fixtures as taskflow_fixtures
@@ -29,7 +27,7 @@ from taskflow.tests import utils
 from taskflow.utils import misc
 
 
-class GreaterThanEqual(object):
+class GreaterThanEqual:
     """Matches if the item is geq than the matchers reference object."""
 
     def __init__(self, source):
@@ -38,10 +36,10 @@ class GreaterThanEqual(object):
     def match(self, other):
         if other >= self.source:
             return None
-        return matchers.Mismatch("%s was not >= %s" % (other, self.source))
+        return matchers.Mismatch(f"{other} was not >= {self.source}")
 
 
-class FailureRegexpMatcher(object):
+class FailureRegexpMatcher:
     """Matches if the failure was caused by the given exception and message.
 
     This will match if a given failure contains and exception of the given
@@ -62,7 +60,7 @@ class FailureRegexpMatcher(object):
                                  (failure, self.exc_class))
 
 
-class ItemsEqual(object):
+class ItemsEqual:
     """Matches the items in two sequences.
 
     This matcher will validate that the provided sequence has the same elements
@@ -122,30 +120,6 @@ class TestCase(base.BaseTestCase):
 
         self.assertRaises(exc_class, access_func)
 
-    def assertRaisesRegex(self, exc_class, pattern, callable_obj,
-                          *args, **kwargs):
-        # TODO(harlowja): submit a pull/review request to testtools to add
-        # this method to there codebase instead of having it exist in ours
-        # since it really doesn't belong here.
-
-        class ReRaiseOtherTypes(object):
-            def match(self, matchee):
-                if not issubclass(matchee[0], exc_class):
-                    compat.reraise(*matchee)
-
-        class CaptureMatchee(object):
-            def match(self, matchee):
-                self.matchee = matchee[1]
-
-        capture = CaptureMatchee()
-        matcher = matchers.Raises(matchers.MatchesAll(ReRaiseOtherTypes(),
-                                  matchers.MatchesException(exc_class,
-                                                            pattern),
-                                  capture))
-        our_callable = testcase.Nullary(callable_obj, *args, **kwargs)
-        self.assertThat(our_callable, matcher)
-        return capture.matchee
-
     def assertGreater(self, first, second):
         matcher = matchers.GreaterThan(first)
         self.assertThat(second, matcher)
@@ -192,7 +166,7 @@ class TestCase(base.BaseTestCase):
 class MockTestCase(TestCase):
 
     def setUp(self):
-        super(MockTestCase, self).setUp()
+        super().setUp()
         self.master_mock = mock.Mock(name='master_mock')
 
     def patch(self, target, autospec=True, **kwargs):
