@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 #    Copyright (C) 2013 Rackspace Hosting All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -20,7 +18,6 @@ import os
 import random
 import tempfile
 
-import six
 import testtools
 
 
@@ -62,7 +59,7 @@ def _get_connect_string(backend, user, passwd, database=None, variant=None):
         raise Exception("Unrecognized backend: '%s'" % backend)
     if not database:
         database = ''
-    return "%s://%s:%s@localhost/%s" % (backend, user, passwd, database)
+    return f"{backend}://{user}:{passwd}@localhost/{database}"
 
 
 def _mysql_exists():
@@ -109,7 +106,7 @@ class SqlitePersistenceTest(test.TestCase, base.PersistenceTestMixin):
         return impl_sqlalchemy.SQLAlchemyBackend(conf).get_connection()
 
     def setUp(self):
-        super(SqlitePersistenceTest, self).setUp()
+        super().setUp()
         self.db_location = tempfile.mktemp(suffix='.db')
         self.db_uri = "sqlite:///%s" % (self.db_location)
         # Ensure upgraded to the right schema
@@ -117,14 +114,14 @@ class SqlitePersistenceTest(test.TestCase, base.PersistenceTestMixin):
             conn.upgrade()
 
     def tearDown(self):
-        super(SqlitePersistenceTest, self).tearDown()
+        super().tearDown()
         if self.db_location and os.path.isfile(self.db_location):
             os.unlink(self.db_location)
             self.db_location = None
 
 
-@six.add_metaclass(abc.ABCMeta)
-class BackendPersistenceTestMixin(base.PersistenceTestMixin):
+class BackendPersistenceTestMixin(base.PersistenceTestMixin,
+                                  metaclass=abc.ABCMeta):
     """Specifies a backend type and does required setup and teardown."""
 
     def _get_connection(self):
@@ -147,7 +144,7 @@ class BackendPersistenceTestMixin(base.PersistenceTestMixin):
         """Cleans up by removing the database once the tests are done."""
 
     def setUp(self):
-        super(BackendPersistenceTestMixin, self).setUp()
+        super().setUp()
         self.backend = None
         try:
             self.db_uri = self._init_db()
@@ -176,7 +173,7 @@ class MysqlPersistenceTest(BackendPersistenceTestMixin, test.TestCase):
             db_uri = _get_connect_string('mysql', USER, PASSWD)
             engine = sa.create_engine(db_uri)
             with contextlib.closing(engine.connect()) as conn:
-                conn.execute("CREATE DATABASE %s" % DATABASE)
+                conn.execute(sa.text("CREATE DATABASE %s" % DATABASE))
         except Exception as e:
             raise Exception('Failed to initialize MySQL db: %s' % (e))
         finally:
@@ -193,7 +190,7 @@ class MysqlPersistenceTest(BackendPersistenceTestMixin, test.TestCase):
         try:
             engine = sa.create_engine(self.db_uri)
             with contextlib.closing(engine.connect()) as conn:
-                conn.execute("DROP DATABASE IF EXISTS %s" % DATABASE)
+                conn.execute(sa.text("DROP DATABASE IF EXISTS %s" % DATABASE))
         except Exception as e:
             raise Exception('Failed to remove temporary database: %s' % (e))
         finally:
@@ -218,7 +215,7 @@ class PostgresPersistenceTest(BackendPersistenceTestMixin, test.TestCase):
             engine = sa.create_engine(db_uri)
             with contextlib.closing(engine.connect()) as conn:
                 conn.connection.set_isolation_level(0)
-                conn.execute("CREATE DATABASE %s" % DATABASE)
+                conn.execute(sa.text("CREATE DATABASE %s" % DATABASE))
                 conn.connection.set_isolation_level(1)
         except Exception as e:
             raise Exception('Failed to initialize PostgreSQL db: %s' % (e))
@@ -242,7 +239,7 @@ class PostgresPersistenceTest(BackendPersistenceTestMixin, test.TestCase):
             engine = sa.create_engine(db_uri)
             with contextlib.closing(engine.connect()) as conn:
                 conn.connection.set_isolation_level(0)
-                conn.execute("DROP DATABASE IF EXISTS %s" % DATABASE)
+                conn.execute(sa.text("DROP DATABASE IF EXISTS %s" % DATABASE))
                 conn.connection.set_isolation_level(1)
         except Exception as e:
             raise Exception('Failed to remove temporary database: %s' % (e))
