@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 #    Copyright (C) 2014 Yahoo! Inc. All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -17,8 +15,7 @@
 from kazoo import client
 from kazoo import exceptions as k_exc
 from oslo_utils import reflection
-import six
-from six.moves import zip as compat_zip
+from oslo_utils import strutils
 
 from taskflow import exceptions as exc
 from taskflow import logging
@@ -26,14 +23,23 @@ from taskflow import logging
 
 LOG = logging.getLogger(__name__)
 
+CONF_TRANSFERS = (
+    ('read_only', strutils.bool_from_string, False),
+    ('randomize_hosts', strutils.bool_from_string, False),
+    ('keyfile', None, None),
+    ('keyfile_password', None, None),
+    ('certfile', None, None),
+    ('use_ssl', strutils.bool_from_string, False),
+    ('verify_certs', strutils.bool_from_string, True))
+
 
 def _parse_hosts(hosts):
-    if isinstance(hosts, six.string_types):
+    if isinstance(hosts, str):
         return hosts.strip()
     if isinstance(hosts, (dict)):
         host_ports = []
-        for (k, v) in six.iteritems(hosts):
-            host_ports.append("%s:%s" % (k, v))
+        for (k, v) in hosts.items():
+            host_ports.append(f"{k}:{v}")
         hosts = host_ports
     if isinstance(hosts, (list, set, tuple)):
         return ",".join([str(h) for h in hosts])
@@ -57,7 +63,7 @@ def prettify_failures(failures, limit=-1):
             pass
         pretty_op += "(%s)" % (", ".join(selected_attrs))
         pretty_cause = reflection.get_class_name(r, fully_qualified=False)
-        prettier.append("%s@%s" % (pretty_cause, pretty_op))
+        prettier.append(f"{pretty_cause}@{pretty_op}")
     if limit <= 0 or len(prettier) <= limit:
         return ", ".join(prettier)
     else:
@@ -70,7 +76,7 @@ class KazooTransactionException(k_exc.KazooException):
     """Exception raised when a checked commit fails."""
 
     def __init__(self, message, failures):
-        super(KazooTransactionException, self).__init__(message)
+        super().__init__(message)
         self._failures = tuple(failures)
 
     @property
@@ -89,7 +95,7 @@ def checked_commit(txn):
         return []
     results = txn.commit()
     failures = []
-    for op, result in compat_zip(txn.operations, results):
+    for op, result in zip(txn.operations, results):
         if isinstance(result, k_exc.KazooException):
             failures.append((op, result))
     if len(results) < len(txn.operations):
@@ -126,8 +132,8 @@ def check_compatible(client, min_version=None, max_version=None):
     """
     server_version = None
     if min_version:
-        server_version = tuple((int(a) for a in client.server_version()))
-        min_version = tuple((int(a) for a in min_version))
+        server_version = tuple(int(a) for a in client.server_version())
+        min_version = tuple(int(a) for a in min_version)
         if server_version < min_version:
             pretty_server_version = ".".join([str(a) for a in server_version])
             min_version = ".".join([str(a) for a in min_version])
@@ -137,8 +143,8 @@ def check_compatible(client, min_version=None, max_version=None):
                                                          min_version))
     if max_version:
         if server_version is None:
-            server_version = tuple((int(a) for a in client.server_version()))
-        max_version = tuple((int(a) for a in max_version))
+            server_version = tuple(int(a) for a in client.server_version())
+        max_version = tuple(int(a) for a in max_version)
         if server_version > max_version:
             pretty_server_version = ".".join([str(a) for a in server_version])
             max_version = ".".join([str(a) for a in max_version])
@@ -175,6 +181,13 @@ def make_client(conf):
     - ``handler``: a kazoo handler object that can be used to provide the
       client with alternate async strategies (the default is `thread`_
       based, but `gevent`_, or `eventlet`_ ones can be provided as needed)
+    - ``keyfile`` : SSL keyfile to use for authentication
+    - ``keyfile_password``: SSL keyfile password
+    -  ``certfile``: SSL certfile to use for authentication
+    - ``ca``: SSL CA file to use for authentication
+    - ``use_ssl``: argument to control whether SSL is used or not
+    - ``verify_certs``: when using SSL, argument to bypass
+        certs verification
 
     .. _client: https://kazoo.readthedocs.io/en/latest/api/client.html
     .. _kazoo: https://kazoo.readthedocs.io/
@@ -188,17 +201,26 @@ def make_client(conf):
     """
     # See: https://kazoo.readthedocs.io/en/latest/api/client.html
     client_kwargs = {
-        'read_only': bool(conf.get('read_only')),
-        'randomize_hosts': bool(conf.get('randomize_hosts')),
         'logger': LOG,
     }
+
+    for key, value_type_converter, default in CONF_TRANSFERS:
+        if key in conf:
+            if value_type_converter is not None:
+                client_kwargs[key] = value_type_converter(conf[key],
+                                                          default=default)
+            else:
+                client_kwargs[key] = conf[key]
+        else:
+            client_kwargs[key] = default
+
     # See: https://kazoo.readthedocs.io/en/latest/api/retry.html
     if 'command_retry' in conf:
         client_kwargs['command_retry'] = conf['command_retry']
     if 'connection_retry' in conf:
         client_kwargs['connection_retry'] = conf['connection_retry']
     hosts = _parse_hosts(conf.get("hosts", "localhost:2181"))
-    if not hosts or not isinstance(hosts, six.string_types):
+    if not hosts or not isinstance(hosts, str):
         raise TypeError("Invalid hosts format, expected "
                         "non-empty string/list, not '%s' (%s)"
                         % (hosts, type(hosts)))
