@@ -187,7 +187,7 @@ def find_subclasses(locations, base_cls, exclude_hidden=True):
             except ValueError:
                 module = importutils.import_module(item)
             else:
-                obj = importutils.import_class('{}.{}'.format(pkg, cls))
+                obj = importutils.import_class(f'{pkg}.{cls}')
                 if not reflection.is_subclass(obj, base_cls):
                     raise TypeError("Object '%s' (%s) is not a '%s' subclass"
                                     % (item, type(item), base_cls))
@@ -317,8 +317,6 @@ def decode_msgpack(raw_data, root_types=(dict,)):
     try:
         data = msgpackutils.loads(raw_data)
     except Exception as e:
-        # TODO(harlowja): fix this when msgpackutils exposes the msgpack
-        # exceptions so that we can avoid catching just exception...
         raise ValueError("Expected msgpack decodable data: %s" % e)
     else:
         return _check_decoded_type(data, root_types=root_types)
